@@ -1,10 +1,25 @@
-/***************************************************************************
- *            cxp-handler.h
+/* $Id: cxp-handler.h,v 1.4 2005/04/17 18:03:18 yasumichi Exp $ */
+/**
+ * \if japanese
+ * @file
+ * @brief եμȥץꥱδϢդ
  *
- *  Mon Nov 29 23:38:45 2004
- *  Copyright  2004  Yasumichi Akahoshi
- *  yasumichi@users.sourceforge.jp
- ****************************************************************************/
+ * եγĥҤ˱ƥե򳫤ץꥱꤹ롣
+ * @author 
+ * @date Tue Mar 29 2005
+ * $Revision: 1.4 $
+ * \endif
+ * \if english
+ * @file
+ * @brief Relation of file type and application
+ *
+ * The application that opens the file according to the extension of the file
+ * is decided.
+ * @author Yasumichi Akahoshi
+ * @date Tue Mar 29 2005
+ * $Revision: 1.4 $
+ * \endif
+ */
 
 /*
  *  This program is free software; you can redistribute it and/or modify
@@ -33,29 +48,87 @@ extern "C"
 #include <glib.h>
 #include <glib-object.h>
 
+/**
+ * \if japanese
+ * @brief CxpHandlerΥˡʼ̻Ҥ롣
+ *
+ * \endif
+ * \if english
+ * @brief A unique identifier of the CxpHandler type is obtained. 
+ *
+ * \endif
+ */
 #define CXP_TYPE_HANDLER				(cxp_handler_get_type ())
+
+/**
+ * \if japanese
+ * @brief objCxpHandler˥㥹Ȥ롣
+ *
+ * \endif
+ * \if english
+ * @brief It is Cast in the CxpHandler type as for obj. 
+ *
+ * \endif
+ */
 #define CXP_HANDLER(obj)				(G_TYPE_CHECK_INSTANCE_CAST ((obj), CXP_TYPE_HANDLER, CxpHandler))
+
+/**
+ * \if japanese
+ * @brief vtableCxpHandlerClass˥㥹Ȥ롣
+ *
+ * \endif
+ * \if english
+ * @brief It is Cast in the CxpHandlerClass type as for vtable. 
+ *
+ * \endif
+ */
 #define CXP_HANDLER_CLASS(vtable)		(G_TYPE_CHECK_CLASS_CAST ((vtable), CXP_TYPE_HANDLER, CxpHandlerClass))
+
+/**
+ * \if japanese
+ * @brief objCxpHandlerǤ뤫ǧ롣
+ *
+ * \endif
+ * \if english
+ * @brief Whether obj is CxpHandler type is confirmed. 
+ *
+ * \endif
+ */
 #define CXP_IS_HANDLER(obj)				(G_TYPE_CHECK_INSTANCE_TYPE ((obj), CXP_TYPE_HANDLER))
+
+/**
+ * \if japanese
+ * @brief vtableCxpHandlerClassǤ뤫ǧ롣
+ *
+ * \endif
+ * \if english
+ * @brief Whether vtable is CxpHandlerClass type is confirmed.
+ *
+ * \endif
+ */
 #define CXP_IS_HANDLER_CLASS(vtable)	(G_TYPE_CHECK_CLASS_TYPE ((vtable), CXP_TYPE_HANDLER))
+
+/**
+ * \if japanese
+ * @brief 󥹥inst顢CxpHandlerClass롣
+ *
+ * \endif
+ * \if english
+ * @brief The CxpHandlerClass type is obtained from instance inst. 
+ *
+ * \endif
+ */
 #define CXP_HANDLER_GET_CLASS(inst)		(G_TYPE_INSTANCE_GET_INTERFACE ((inst), CXP_TYPE_HANDLER, CxpHandlerClass))
 
-/*
- * Type macros.
- */
-
-	typedef struct _CxpHandler CxpHandler;
-	typedef struct _CxpHandlerClass CxpHandlerClass;
-
-	struct _CxpHandler
+	typedef struct
 	{
 		GObject parent;
-	};
+	} CxpHandler;
 
-	struct _CxpHandlerClass
+	typedef struct
 	{
 		GObjectClass parent;
-	};
+	} CxpHandlerClass;
 
 /* used by CXP_TYPE_HANDLER */
 	GType cxp_handler_get_type (void);
