@@ -1,4 +1,4 @@
-/* $Id: cxp-handler.c,v 1.15 2005/08/10 16:05:22 yasumichi Exp $ */
+/* $Id: cxp-handler.c,v 1.18 2005/09/07 09:55:04 yasumichi Exp $ */
 /**
  * \if japanese
  * @file
@@ -6,7 +6,7 @@
  *
  * @author 
  * @date Tue Mar 29 2005
- * $Revision: 1.15 $
+ * $Revision: 1.18 $
  * \endif
  * \if english
  * @file
@@ -14,7 +14,7 @@
  *
  * @author Yasumichi Akahoshi
  * @date Tue Mar 29 2005
- * $Revision: 1.15 $
+ * $Revision: 1.18 $
  * \endif
  */
 
@@ -251,8 +251,9 @@ CxpHandler *cxp_handler_new (void)
 void cxp_handler_launch (CxpHandler * handler, const gchar * fullpath)
 {
 	CxpHandlerPrivate *priv = CXP_HANDLER_GET_PRIVATE(handler);
-	gchar *gconf_dir;
+	gchar *key;
 	gchar *mime_type;
+	gchar *file_type;
 	gchar *cmd = NULL;
 	gchar *fullcmd;
 	gchar *message;
@@ -262,14 +263,16 @@ void cxp_handler_launch (CxpHandler * handler, const gchar * fullpath)
 	g_return_if_fail (fullpath != NULL);
 
 	mime_type = cxp_get_mime_type_for_file (fullpath);
-	gconf_dir = g_strdup_printf ("/apps/cxp/mime-types/%s/open", mime_type);
-	cmd = gconf_client_get_string (priv->client, gconf_dir, NULL);
+	key = g_strdup_printf ("/apps/cxp/mime-types/%s/open", mime_type);
+	g_strdelimit (key, "+", '@');
+	cmd = gconf_client_get_string (priv->client, key, NULL);
 	if (cmd == NULL)
 	{
+		file_type = cxp_get_mime_comment (mime_type);
 		message =
 			g_strdup_printf (_("Please input the command that opens the file whose type is %s"),
-					mime_type);
-		dialog = cxp_entry_dialog_new (_("Undefined extension"),
+					file_type);
+		dialog = cxp_entry_dialog_new (_("Undefined operation"),
 				message, "");
 		if (gtk_dialog_run (GTK_DIALOG (dialog)) ==
 				GTK_RESPONSE_OK)
@@ -278,10 +281,11 @@ void cxp_handler_launch (CxpHandler * handler, const gchar * fullpath)
 				(CXP_ENTRY_DIALOG (dialog));
 			if ((cmd != NULL) && (strlen (cmd) > 0))
 			{
-				gconf_client_set_string (priv->client, gconf_dir, cmd, NULL);
+				gconf_client_set_string (priv->client, key, cmd, NULL);
 			}
 		}
 		gtk_widget_destroy (dialog);
+		g_free (file_type);
 		g_free (message);
 	}
 	g_free (mime_type);
